# it is just for testing
from Py2PostgreS import *
from Py2PostgreS.Py2SQL import Py2SQL


connection = Py2SQL()
db = {'name': 'postgres', 'user': 'postgres', 'password': 'postgres', 'host': 'localhost'}
connection.db_connect(db)

connection.db_disconnect()



import psycopg2


def should_be_connected(func):
    def wrapper(*args):
        if args[0].was_connected():
            return func(args)
        else:
            raise RuntimeError("wasn't connected")

    return wrapper


class Py2SQL:
    __was_connected = False
    __conn = None

    def was_connected(self):
        return self.__was_connected

    def db_connect(self, db):
        self.__conn = psycopg2.connect(dbname=db['name'], user=db['user'],
                                       password=db['password'], host=db['host'])
        self.__was_connected = True

    # @should_be_connected
    def db_disconnect(self):
        self.__was_connected = False
        self.__conn = None



from setuptools import setup

setup(name='Py2PostgreS',
      version='0.2.2',
      description='Py to postgreSQL',  # Small descriptions.
      author='Blahyi Andrii, Kushnirenko Mariia, Tochanenko Vladislav, Velychko Taisiia',  # Optional in test.PyPI.
      author_email='blagij00@gmail.com',  # Optional in test.PyPI.
      license='MIT',
      packages=['Py2PostgreS'],
      zip_safe=False)
